#! /bin/bash

#  Utility functions to configure LEPTON. Used by all scripts

#  The names of the variables used in the bash scripts
bash_keys="lepton_host nodes_hosts oppnet_adapter start_deferred jitter time_margin lepton_start_time nodes_steps oppnet_adapter_classpath"

#---------------------------------------------------------------------
#  Give the maven local repository
#---------------------------------------------------------------------
local_repository() {
    mvn help:evaluate -Dexpression=localRepository |grep basedir | sed 's/<\/\?basedir>//g' | sed 's/ //g'
}

#---------------------------------------------------------------------
#  Make a classpath with all the jar files in the libs/ directory
#---------------------------------------------------------------------
make_classpath() {
    
    libs_dir=${lepton_home}/libs
    
    for i in ${libs_dir}/*.jar ; do
	classpath="${i}:${classpath}"
    done

    if [ "${oppnet_adapter_classpath}" != "" ]; then
	classpath="${oppnet_adapter_classpath}:${classpath}"
    fi
    
    echo "${classpath}"    
}

#---------------------------------------------------------------------
#  Initialize bash variables from the configuration properties. Use
#  previousely saved properties if any
#---------------------------------------------------------------------
load_saved_config() {
    
    if [[ "${LEPTON_VAR}" != "" ]]; then
	log_dir=${LEPTON_VAR}
	echo "Using LEPTON_VAR: \"${LEPTON_VAR}\""    
    else
	load_config $*
	echo "No LEPTON_VAR set. Using \"${log_dir}\""
    fi
    
    if [ -f ${log_dir}/.config ]; then
	echo "Loading the previous configuration from ${log_dir}/.config"
	load_config $(cat ${log_dir}/.config)
    elif [[ "${LEPTON_VAR}" != "" ]]; then
	load_config $*
    fi
}

#---------------------------------------------------------------------
#  Initialize bash variables from the configuration properties
#---------------------------------------------------------------------
load_config() {
    #  Load the default configuration file
    . ${lepton_home}/conf/lepton.conf

    #  Load the configuration properties in the script arguments
    for arg in $*; do
	key=${arg%=*}
	value=${arg#*=}
	if [ "$key" != "$value" ]; then
	    case "$key" in
		"conf")       #  load the configuration file
		    . "$value" 
		    ;;
		*)            #  initialize the variable
		    eval ${key}="${value}"
		    ;;
	    esac
	fi
    done

    #  Create seed if it is not set
    if [ "${seed}" == "" ]; then
	seed=$(date +%s)
    fi    
}

#---------------------------------------------------------------------
#  Display the bash properties having a non empty value
#---------------------------------------------------------------------
show_config() {
    for key in ${bash_keys}; do
	val=${!key}
	if [ "${val}" != "" ]; then
	    str=""
	    for (( i = ${#key}; i < 30; i++ )); do
		str="${str} "
	    done
	    echo "   ${key}${str}: ${val}"
	fi
    done
}
