#! /bin/bash

#  Populate the ../../libs/ directory with the LEPTON dependencies given by
#  maven, using the ../../pom.xml file 

#  The directory where the dependencies should be copied
script_dir=$(dirname $0)
libs_dir=`realpath ${script_dir}/../../libs`

#  The group and artifact ids that should be excluded
excluded_groups=bouncycastle,org.jfree,com.lowagie,junit,org.apache.commons,org.hamcrest,xml-apis
excluded_artifacts=mbox2

#  Usage message
usage() {
    echo "Usage: load_libs [-c|-l]"
    echo "Populate the ${libs_dir} directory with the LEPTON dependencies"
    echo "   -c   copy libraries (default)"
    echo "   -l   make symbolic links"
    exit -1
}

#  Populate the libs/ directory with symbolic links to the LEPTON
#  dependencies
link_dependencies() {
    #  List dependencies
    mvn dependency:list \
	-DincludeScope=compile \
	-DoutputAbsoluteArtifactFilename=true \
	-DoutputFile=${libs_dir}/dependencies \
	-DoutputScope=false \
	-DexcludeGroupIds=${excluded_groups} \
	-DexcludeArtifactIds=${excluded_artifacts}

    #  Make symbolic links
    for i in `awk -F ":" '{ print $NF }' ${libs_dir}/dependencies`; do
	ln -f -s $i ${libs_dir}
    done
}

#  Populate the libs/ directory with copies of the LEPTON dependencies
copy_dependencies() {
    mvn dependency:copy-dependencies \
	-DincludeScope=compile \
	-DoutputDirectory=${libs_dir}/ \
	-DexcludeGroupIds=${excluded_groups} \
	-DexcludeArtifactIds=${excluded_artifacts}
}

#----------------------------------------------------------------------
#  Main
#----------------------------------------------------------------------
#  Check arguments
if [ $# -eq 0 ]; then
    option="-c"
elif [ "$1" != "-l" ] && [ "$1" != "-c" ]; then
    usage
else
    option=$1
fi

#  Check the maven installation
command -v mvn >/dev/null 2>&1 || {
    echo "\"mvn\" command not found. Cannot load the LEPTON dependencies."
    exit -1
}    

#  Initialize the libs directory
if [ ! -d ${libs_dir} ]; then
    mkdir -p ${libs_dir}
fi

#  Create symbolic links or copies
user_dir=$(pwd)
cd ${script_dir}/../..
if [ "$option" == "-l" ]; then
    link_dependencies
else
    copy_dependencies
fi
cd ${user_dir}

